#!/bin/bash
#Mythbuntu live cd generating script

#####################
#
# License:
#
# Copyright © 2007  Mario Limonciello
#
# This script is loosely based from Linux Mint's live CD building script remastersys.
#
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# On Ubuntu systems, a copy of the GPLv3 is available in /usr/share/common-licenses/GPL-3
#
#####################
#
# Requirements:
# * Root permissions
# * debootstrap taken from ubuntu/main of the target Ubuntu release
# * Approx 2GB during the build process
#  - 1GB in the build location
#  - 1GB on the partition containing /var/cache/apt/archives
#    This script will link externally to /var/cache/apt/archives for
#    quicker future builds.
#
#####################
#
# Release Configuration & Environment Variables:
#

#Working Directory.  You will need 2-3 GB space here.
if [ -z "$BASE_INSTALL" ] ; then
    BASE_INSTALL='/tmp/mythbuntu_iso'
fi

#Base mirror for repositories
if [ -z "$BASE_MIRROR" ] ; then
#    BASE_MIRROR='http://mirror.imbrandon.com/ubuntu/'
    BASE_MIRROR='http://mirror.cs.umn.edu/ubuntu/'
#    BASE_MIRROR='http://ftp.ussg.iu.edu/linux/ubuntu'
#    BASE_MIRROR='http://archive.ubuntu.com/ubuntu'
fi

#Proxy if needed
if [ -z "$http_proxy" ] ; then
    http_proxy=""
fi

#Number of APT Retries
if [ -z "$APT_RETRIES" ] ; then
    APT_RETRIES=25
fi

#Ubuntu Release to base from
if [ -z "$BASE_RELEASE" ] ; then
    BASE_RELEASE='gutsy'
fi

#Ubuntu Version to base from
if [ -z "$VERSION" ] ; then
    VERSION='7.10'
fi

#Mythbuntu Release
if [ -z "$MYTHBUNTU_RELEASE" ] ; then
    MYTHBUNTU_RELEASE='alpha3'
fi

#Architecture we are building on
if [ -z "$ARCHITECTURE" ] ; then
    ARCHITECTURE='i386'
fi

#Place to put the final ISO when done.  You will need 300-700 MB here.
if [ -z "$NEW_DIRECTORY" ] ; then
    NEW_DIRECTORY="/var/cache/mythbuntu_isos/result"
fi

#For minor changes not requiring an entire rebuild
if [ -z "$DONT_CLEAN_SYSTEM" ]; then
    DONT_CLEAN_SYSTEM="no"
fi

#Install all packages and configuration
if [ -z "$BUILD_SYSTEM" ]; then
    BUILD_SYSTEM="yes"
fi

#Build the target ISO image
if [ -z "$BUILD_ISO" ]; then
    BUILD_ISO="yes"
fi

#APT Key that we sign our packages with
if [ -z "$APT_KEY" ]; then
    APT_KEY="EEED06D0"
fi

#Enable the on CD repository
if [ -z "$CDREPOSITORY" ]; then
    CDREPOSITORY="yes"
fi

#####################
#
# Experimental Environment Variables:
# WARNING: These will produce unpredictable results

#For testing the port to non root user
#FAKECHROOT='no'

#####################
#
# Calculated env variables (don't change)
#

#Setup our date that is used throughout the rest of the build
DATE=`date '+%y%m%d'`

#Find the user building this
ID=`id -u`

#ISO & MD5Sum file names
NEW_ISO="mythbuntu-$VERSION~$DATE-$ARCHITECTURE.iso"
NEW_MD5="$NEW_ISO.md5sum"

#####################
#
# Test enviornment, cleanup old builds, and pre-chroot steps
#

#Step 0 - Check users, Clean up old stuf
if [ -z $FAKECHROOT ] ; then
    if [ $ID != '0' ] ; then
        echo "Not building with fakechroot, need to build as root"
        exit 1
    else
        echo "Initializing normal Mythbuntu build initiated by $ID at `date`"
    fi
else
    if [ $ID != '0' ] ; then
        echo "Initializing fakechroot'ed Mythbuntu build initiated by $ID at `date`"
    else
        echo "Don't build in fakechroot as root."
        exit 1
    fi
fi
if [ $BASE_INSTALL = '/' ] ; then
    echo "Aborting build.  BASE_INSTALL was set to be / which would obliterate this filesystem."
    exit 2
fi
if [ -d work ] ; then
    #when building on pegasus, we build from a work directory
    cd work
fi
mkdir -p $BASE_INSTALL
umount $BASE_INSTALL/proc 2>&1
umount $BASE_INSTALL/sys 2>&1
umount $BASE_INSTALL/dev/pts 2>&1
umount $BASE_INSTALL/var/cache/apt/archives 2>&1
find   $BASE_INSTALL/lib/modules/ -name volatile | xargs umount 2>&1
rm -rf $BASE_INSTALL/home/remastersys/ISOTMP/casper/filesystem.squashfs
rm -rf $BASE_INSTALL/home/remastersys/mythbuntu.iso
if [ "$DONT_CLEAN_SYSTEM" != "yes" ] ; then
    echo "Starting cleanup for Mythbuntu build, `date`"
    rm -rf $BASE_INSTALL/*
else
    echo "Skipping clean because DONT_CLEAN_SYSTEM variable was set to yes."
    rm $BASE_INSTALL/home/remastersys/ISOTMP/ubuntu #symlink is recreated (Prevent the error)
fi


#Step 1 - debootstrap new base system
if [ "$DONT_CLEAN_SYSTEM" != "yes" ] ;then
    echo "Starting actual Mythbuntu build, `date`"
    if [ -z $FAKECHROOT ] ; then
        debootstrap --arch $ARCHITECTURE $BASE_RELEASE $BASE_INSTALL $BASE_MIRROR
    else
        fakeroot fakechroot debootstrap  --variant=fakechroot --arch $ARCHITECTURE $BASE_RELEASE $BASE_INSTALL $BASE_MIRROR
    fi
else
    echo "Skipping debootstrap, but starting mythbuntu build, `date`"
fi

#Step 2, Prep remastersys directory
mkdir -p $BASE_INSTALL/home/remastersys
mkdir -p $BASE_INSTALL/home/remastersys/dummysys
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/proc
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/tmp
chmod ug+rwx,o+rwt $BASE_INSTALL/home/remastersys/dummysys/tmp
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/sys
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/mnt
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/media
mkdir -p $BASE_INSTALL/home/remastersys/dummysys/var
mkdir -p $BASE_INSTALL/var/cache/apt/archives/partial
mkdir -p $BASE_INSTALL/tmp
mkdir -p $BASE_INSTALL/etc/apt
cp -L -R ISOTMP $BASE_INSTALL/home/remastersys
mkdir -p $BASE_INSTALL/home/remastersys/ISOTMP/casper
ln -s . $BASE_INSTALL/home/remastersys/ISOTMP/ubuntu

#Step 3 - copy over networking config
if [ -f /etc/resolv.conf ]; then
    cp /etc/resolv.conf $BASE_INSTALL/etc/.
fi
if [ -f /etc/apt/apt.conf ]; then
    cp /etc/apt/apt.conf  $BASE_INSTALL/etc/apt/.
fi

#Step 4, Copy in our apt key
cp $APT_KEY.gpg $BASE_INSTALL/tmp

#Step 5, Copy in our background files
cp background_install.xpm $BASE_INSTALL/tmp

#Step 5a, make symlinks to directories we will need to access in fakechroot mode (Experimental)
if [ ! -z $FAKECHROOT ] ; then
    rm $BASE_INSTALL/proc -r
    rm $BASE_INSTALL/sys -r
    rm $BASE_INSTALL/dev -r
    ln -s /proc $BASE_INSTALL/proc
    ln -s /dev  $BASE_INSTALL/dev
    ln -s /sys  $BASE_INSTALL/sys
fi

#####################################
#Step 6, generate our chroot system script
cat <<EOCHROOT >$BASE_INSTALL/tmp/mythbuntu-system-script
#!/bin/bash
#Mythbuntu chroot system script
# Copyright © 2007  Mario Limonciello

export DEBIAN_FRONTEND=noninteractive

#Step A: Don't start any init scripts in this env
#This will keep any build machines clean of rogue processes
mv /sbin/start-stop-daemon /sbin/start-stop-daemon.real
cat <<EOF > /sbin/start-stop-daemon
#!/bin/sh
echo 1>&2
echo 'Warning: Fake start-stop-daemon called, doing nothing.' 1>&2
exit 0
EOF
cat <<EOF > /usr/sbin/policy-rc.d
#!/bin/sh
exit 101
EOF
chmod 755 /usr/sbin/policy-rc.d
chmod 755 /sbin/start-stop-daemon

#Step B: Install the minimal ubuntu system in fakechroot mode, mount imaginary systems in normal mode
if [ ! -z $FAKECHROOT ] ; then
    #Note, this needs to be forced because we don't yet have any apt keys
    apt-get install ubuntu-minimal -y --force-yes -o Acquire::Retries=$APT_RETRIES
    echo "Running fakechroot"
else
    mount -t proc   none  /proc
    mount -t devpts none  /dev/pts
    mount -t sysfs  sysfs /sys
fi

#Step C: Generate sources.list
cat <<EOF >/etc/apt/sources.list
deb $BASE_MIRROR $BASE_RELEASE main restricted universe multiverse
deb $BASE_MIRROR $BASE_RELEASE-updates main restricted universe multiverse
deb $BASE_MIRROR $BASE_RELEASE-security main restricted universe multiverse
deb $BASE_MIRROR $BASE_RELEASE-backports main restricted universe multiverse
deb http://www.mythbuntu.org/files/packages $BASE_RELEASE mythbuntu
deb-src $BASE_MIRROR $BASE_RELEASE-updates main restricted universe multiverse
deb-src $BASE_MIRROR $BASE_RELEASE universe multiverse main restricted
deb-src $BASE_MIRROR $BASE_RELEASE-backports main restricted universe multiverse
deb-src $BASE_MIRROR $BASE_RELEASE-security main restricted universe multiverse
deb-src http://www.mythbuntu.org/files/packages $BASE_RELEASE mythbuntu
EOF

#Step D: Set default locale and timezone
localedef -i en_US -c -f UTF-8 en_US.UTF-8
echo "America/Chicago" > /etc/timezone
cp /usr/share/zoneinfo/America/Chicago /etc/localtime

#Step E: Set up base configuration files for the rest of installation
cat <<EOF >/etc/network/interfaces
auto lo
iface lo inet loopback
EOF
cat <<EOF >/etc/kernel-img.conf
do_symlinks = yes
do_initrd = yes
EOF
cat <<EOF >/etc/casper.conf
# This file should go in /etc/casper.conf
# Supported variables are:
# USERNAME, USERFULLNAME, HOST, BUILD_SYSTEM

export USERNAME="ubuntu"
export USERFULLNAME="Live session user"
export HOST="ubuntu"
export BUILD_SYSTEM="Ubuntu"
EOF

#Step F: Update the bootstrapped install
apt-key add /tmp/$APT_KEY.gpg
apt-get update
apt-get upgrade -y

#Step G: install the standard ubuntu utils
apt-get install -y -o Acquire::Retries=$APT_RETRIES ubuntu-standard

#Step H: Install a kernel & Restricted modules
apt-get install -y -o Acquire::Retries=$APT_RETRIES linux-image-generic linux-restricted-modules-generic restricted-manager

#Step I: install X, openbox, gdm, gnome-screensaver, idesk, feh, theme, firefox, libgnome2-perl, gnome-volume-manager
apt-get install -y -o Acquire::Retries=$APT_RETRIES openbox gdm xserver-xorg xterm xfonts-100dpi xfonts-75dpi xfonts-base gnome-screensaver gsfonts-x11 idesk feh firefox libgnome2-perl update-notifier update-manager-core gnome-volume-manager apport acpi-support acpi openssh-server vnc4-common

#Step J: install media players and mythtv frontend and all plugins
apt-get install -y -o Acquire::Retries=$APT_RETRIES vlc mythtv-frontend mythvideo mythdvd mythnews mythflix mythweather mythgame mythmusic mythgallery mythtv-themes mythphone mytharchive mythcontrols mythbrowser mplayer xine-ui

#Step K: install modified artwork that we assembled
apt-get install -y -o Acquire::Retries=$APT_RETRIES mythbuntu-artwork-usplash gtk2-engines-mythbuntu mythbuntu-gdm-theme mythbuntu-default-settings mythbuntu-live-autostart mythbuntu-lirc-generator
cp /etc/skel/.gtkrc-2.0 /root
cp /etc/skel/.gtkrc-2.0 /home/mythtv
chown mythtv:mythtv /home/mythtv/.gtkrc-2.0

#Step M: Grab Live Cd Build Dependencies
apt-get install -y -o Acquire::Retries=$APT_RETRIES coreutils mkisofs findutils bash passwd sed squashfs-tools casper rsync mount eject libdebian-installer4 os-prober ubiquity ubiquity-frontend-mythbuntu ubiquity-ubuntu-artwork user-setup memtest86+ dpkg-dev discover1 language-selector-common

#Step N: Preinstall all other options
apt-get -y install -o Acquire::Retries=$APT_RETRIES ubuntu-mythtv-frontend mythtv-backend-master mythweb mythtv samba

#Step O: unmount imaginary filesystems
#the last one gets mounted during l-r-m install, but can be from many different kernels
if [ -z $FAKECHROOT ] ; then
    umount /proc
    umount /dev/pts
    umount /sys
    umount /var/cache/apt/archives
    find /lib/modules/ -name volatile | xargs umount
fi

#Step P: Remove our archives directory that was linked in from the outside world
rm -rf /var/cache/apt/archives
mkdir -p /var/cache/apt/archives/partial

#Step Q: Build CD information & CD repository
cd /
mkdir -p /home/remastersys/ISOTMP/.disk
cat > /home/remastersys/ISOTMP/.disk/info << EOF
Mythbuntu $VERSION "$BASE_RELEASE" - $MYTHBUNTU_RELEASE $ARCHITECTURE ($DATE)
EOF
cat > /home/remastersys/ISOTMP/.disk/release_notes_url << EOF
www.mythbuntu.org/$VERSION/release_notes
EOF
if [ "$CDREPOSITORY" = "yes" ]; then
    #Acquire Packages
    apt-get install -y -d -o Acquire::Retries=$APT_RETRIES vnc4server nfs-kernel-server portmap nvidia-glx
    apt-get install -y -d -o Acquire::Retries=$APT_RETRIES xorg-driver-fglrx
    #Place In the directory structure
    mkdir -p /home/remastersys/ISOTMP/pool/main
    mkdir -p /home/remastersys/ISOTMP/pool/main/g
    mv /var/cache/apt/archives/g* /home/remastersys/ISOTMP/pool/main/g
    mkdir -p /home/remastersys/ISOTMP/pool/main/n
    mv /var/cache/apt/archives/nfs* /home/remastersys/ISOTMP/pool/main/n
    mkdir -p /home/remastersys/ISOTMP/pool/main/p
    mv /var/cache/apt/archives/port* /home/remastersys/ISOTMP/pool/main/p
    mkdir -p /home/remastersys/ISOTMP/pool/main/l
    mv /var/cache/apt/archives/l* /home/remastersys/ISOTMP/pool/main/l
    mkdir -p /home/remastersys/ISOTMP/pool/main/v
    mv /var/cache/apt/archives/v* /home/remastersys/ISOTMP/pool/main/v
    mkdir -p /home/remastersys/ISOTMP/pool/restricted
    mkdir -p /home/remastersys/ISOTMP/pool/restricted/n
    mv /var/cache/apt/archives/n* /home/remastersys/ISOTMP/pool/restricted/n
    mkdir -p /home/remastersys/ISOTMP/pool/restricted/x
    mv /var/cache/apt/archives/x* /home/remastersys/ISOTMP/pool/restricted/x
    #Write Release Files
    mkdir -p /home/remastersys/ISOTMP/dists/$BASE_RELEASE/main/binary-$ARCHITECTURE
    mkdir -p /home/remastersys/ISOTMP/dists/$BASE_RELEASE/main/source
    cat > /home/remastersys/ISOTMP/dists/$BASE_RELEASE/main/binary-$ARCHITECTURE/Release <<EOF

Archive: $BASE_RELEASE
Version: $VERSION
Component: main
Origin: Ubuntu
Label: Ubuntu
Architecture: $ARCHITECTURE
EOF
    mkdir -p /home/remastersys/ISOTMP/dists/$BASE_RELEASE/restricted/binary-$ARCHITECTURE
    mkdir -p /home/remastersys/ISOTMP/dists/$BASE_RELEASE/restricted/source
    cat > /home/remastersys/ISOTMP/dists/$BASE_RELEASE/restricted/binary-$ARCHITECTURE/Release <<EOF

Archive: $BASE_RELEASE
Version: $VERSION
Component: restricted
Origin: Ubuntu
Label: Ubuntu
Architecture: $ARCHITECTURE
EOF
    cd /home/remastersys/ISOTMP
    dpkg-scanpackages pool/main /dev/null > dists/$BASE_RELEASE/main/binary-$ARCHITECTURE/Packages
    cat dists/$BASE_RELEASE/main/binary-$ARCHITECTURE/Packages | gzip -9 > dists/$BASE_RELEASE/main/binary-$ARCHITECTURE/Packages.gz
    dpkg-scanpackages pool/restricted /dev/null > dists/$BASE_RELEASE/restricted/binary-$ARCHITECTURE/Packages
    cat dists/$BASE_RELEASE/restricted/binary-$ARCHITECTURE/Packages | gzip -9 > dists/$BASE_RELEASE/restricted/binary-$ARCHITECTURE/Packages.gz
fi

#Step R: prepare ubiquity
rm -f /usr/share/ubiquity/apt-setup
echo "#do nothing" > /usr/share/ubiquity/apt-setup
chmod 755 /usr/share/ubiquity/apt-setup
dpkg-reconfigure casper

#Step S: copy current kernel/initrd
cp /vmlinuz /home/remastersys/ISOTMP/casper/
cp /initrd.img /home/remastersys/ISOTMP/casper/initrd.gz
cp /boot/memtest86+.bin /home/remastersys/ISOTMP/install/mt86plus

#Step T: remove our proxy conf file
if [ -f /etc/apt/apt.conf ]; then
    rm /etc/apt/apt.conf
fi

#Step U: Remove our fake scripts
rm /usr/sbin/policy-rc.d
rm /sbin/start-stop-daemon
mv /sbin/start-stop-daemon.real /sbin/start-stop-daemon

#Step V: Remove Autostarting of:
update-rc.d -f mythtv-backend remove
update-rc.d -f mysql remove
update-rc.d -f apache2 remove
update-rc.d -f ntp remove
update-rc.d -f samba remove
update-rc.d -f ssh remove

#Step W: Re-enable apache upon reinstall
cat > /etc/default/apache2 <<EOF
# 0 = start on boot; 1 = don't start on boot
NO_START=0
EOF
EOCHROOT

#Step 6, generate our chroot iso script
cat <<EOCHROOT >$BASE_INSTALL/tmp/mythbuntu-iso-script
#!/bin/bash
#Mythbuntu chroot iso build script
# Copyright © 2007  Mario Limonciello

#Step X: Create Live Disk User & prep their personalized desktop
groupadd -g 999 ubuntu
useradd -g 999 -u 999 -s /bin/bash -m -G adm,dialout,cdrom,floppy,audio,dip,video,plugdev,mythtv ubuntu
mv /tmp/background_install.xpm /home/ubuntu/.background.xpm
rm /home/ubuntu/.idesktop/*
cat > /home/ubuntu/.idesktop/gmplayer.lnk <<EOF
table Icon
  Caption: GMplayer
  CaptionTip: Runs mplayer from livecd
  Command: gmplayer
  Icon: /usr/share/pixmaps/mplayer.xpm
  FontColor: #FFFFFA
  Width: 48
  Height: 48
  X: 273
  Y: 0
end
EOF
cat > /home/ubuntu/.idesktop/mythfrontend.lnk <<EOF
table Icon
  Caption: Mythbuntu Live Frontend
  CaptionTip: Runs directly from live cd
  Command: echo | sudo mythbuntu-startup
  Icon: /usr/share/mythtv/themes/blue/myth_tv_logo.png
  FontColor: #FFFFFA
  Width: 145
  Height: 48
  X: 31
  Y: 0
end
EOF
cat > /home/ubuntu/.idesktop/ubiquity.lnk <<EOF
table Icon
  Caption: Install Mythbuntu
  Caption Tip: Installs Mythbuntu directly to this system
  Command: echo | sudo -S /usr/bin/ubiquity mythbuntu_ui
  Icon: /usr/share/pixmaps/ubiquity.png
  FontColor: #FFFFFA
  Width: 64
  Height: 64
  X: 81
  Y: 85
end
EOF
cat > /home/ubuntu/.idesktop/vlc.lnk <<EOF
table Icon
  Caption: VLC
  CaptionTip: Runs VLC from live cd
  Command: vlc
  Icon: /usr/share/vlc/vlc.xpm
  FontColor: #FFFFFA
  Width: 48
  Height: 48
  X: 193
  Y: 0
end
EOF
cat > /home/ubuntu/.idesktop/firefox.lnk <<EOF
table Icon
  Caption: Firefox
  CaptionTip: Runs Firefox from live cd
  Command: firefox http://www.mythbuntu.org
  Icon: /usr/share/pixmaps/firefox.png
  FontColor: #FFFFFA
  Width: 48
  Height: 48
  X: 353
  Y: 0
end
EOF
chown 999:999 /home/ubuntu/.idesk* -R

#Step Y: Generate manifests and control scripts
dpkg-query -W --showformat='\${Package} \${Version}\n' | grep -v deinstall > /home/remastersys/ISOTMP/casper/filesystem.manifest
cat > /home/remastersys/control <<EOF
/casper/d
/libdebian-installer4/d
/os-prober/d
/ubiquity/d
/user-setup/d
/gnome-mount/d
/gnome-volume-manager/d
EOF
sed -f /home/remastersys/control < /home/remastersys/ISOTMP/casper/filesystem.manifest > /home/remastersys/ISOTMP/casper/filesystem.manifest-desktop

#Step Z: Prep remastersys directories
find /var/log -name *log.* > /home/remastersys/varexc
find /var -name *.pid >> /home/remastersys/varexc
find /var/tmp -name *cache* >> /home/remastersys/varexc
rsync --exclude-from=/home/remastersys/varexc -av /var/. /home/remastersys/dummysys/var/.

#Step Za: create squashfs
if [ ! -z $FAKECHROOT ] ; then
    #Clean up directories before making
    rm -r /proc /sys /dev
    mkdir -p /proc
    mkdir -p /dev
    mkdir -p /sys
fi
mksquashfs / /home/remastersys/ISOTMP/casper/filesystem.squashfs -e \
.thumbnails \
Cache \
/etc/X11/xorg.conf \
/etc/resolv.conf \
/etc/mtab \
/etc/fstab \
/media \
/mnt \
/proc \
/sys \
/tmp \
/var \
/home/remastersys

#Step Zb: add other live cd folder requirements
mksquashfs /home/remastersys/dummysys/ /home/remastersys/ISOTMP/casper/filesystem.squashfs

#Step Zc: remove our live user
userdel ubuntu

#Step Zd: create a md5sum for the ISO
cd /home/remastersys/ISOTMP && find . -type f -print0 | xargs -0 md5sum | sed /md5sum/d | sed /boot.cat/d | sed /isolinux.bin/d > md5sum.txt

#Step Ze: create ISO
mkisofs    \
 -r    \
 -V "Mythbuntu $VERSION $MYTHBUNTU_RELEASE"    \
 -cache-inodes    \
 -J    \
 -l    \
 -b isolinux/isolinux.bin    \
 -c isolinux/boot.cat    \
 -no-emul-boot    \
 -boot-load-size 4    \
 -boot-info-table    \
 -o /home/remastersys/mythbuntu.iso "/home/remastersys/ISOTMP"
ls -hs /home/remastersys/mythbuntu.iso
EOCHROOT

#####################################
#Step 7, run our chroot script
chmod +x $BASE_INSTALL/tmp/mythbuntu-system-script
chmod +x $BASE_INSTALL/tmp/mythbuntu-iso-script
if [ ! -z $FAKECHROOT ] ; then
    TIME="The fakechroot build process ran for %E." time fakeroot fakechroot chroot $BASE_INSTALL /tmp/mythbuntu-system-script
    TIME2="The fakechroot build process ran for %E." time fakeroot fakechroot chroot $BASE_INSTALL /tmp/mythbuntu-iso-script
else

    if [ $BUILD_SYSTEM = "yes" ]; then
        mount --bind /var/cache/apt/archives $BASE_INSTALL/var/cache/apt/archives
        TIME="The chroot build process ran for %E." time chroot $BASE_INSTALL /tmp/mythbuntu-system-script
    else
        echo "Skipping chroot build process as requested by user."
    fi
    if [ $BUILD_ISO = "yes" ]; then
        TIME2="The chroot iso process ran for %E." time chroot $BASE_INSTALL /tmp/mythbuntu-iso-script
    else
        echo "Skipping chroot iso process as requested by user."
    fi


fi

#####################################
#Step 8, Cleanup
rm $BASE_INSTALL/tmp/mythbuntu-system-script
rm $BASE_INSTALL/tmp/mythbuntu-iso-script

#####################################
#Step 9, Finished up
#####################################
if [ $BUILD_ISO = "yes" ]; then
    mv $BASE_INSTALL/home/remastersys/mythbuntu.iso $NEW_DIRECTORY/$NEW_ISO
    cd $NEW_DIRECTORY
    md5sum $NEW_ISO > $NEW_MD5
    echo "Your mythbuntu image generation completed at `date`"

    echo "The ISO image is located in $NEW_DIRECTORY/$NEW_ISO"
    echo "The ISO md5sum is located in $NEW_DIRECTORY/$NEW_MD5"
else
    echo "The base install is located in $BASE_INSTALL"
    echo "No ISO image was generated as requested by user."
fi
