#!/bin/sh
# Weekly MythTV cron job build script
# Mario Limonciello, April-June 2007

# NOTE:
# The following needs to be done to prep the build process
#  * Need dpatch, gcc, debhelper, devscripts, subversion installed
#  * Move a current mythtv-*/debian to $BUILD_LOCATION/debian-mythtv (Shipped) 
#  * Move a current mythplugins-*/debian to $BUILD_LOCATION/work/debian-mythplugins (Shipped)
#  * Revoke any unnecessary patches in both $BUILD_LOCATION/work/debian-* directories
#  * A proper /etc/falcon.ini to reflect build locations (example file shipped with script)
#  * A proper gpg key (no passphrase) (Not shipped)

#These need to be updated during new 
#ubuntu or mythtv releases
UBUNTU_RELEASE="feisty"
UBUNTU_VERSION="7.04"
SVN_MAJOR_RELEASE="20"
SVN_MINOR_RELEASE="1"
SVN_TYPE="fixes"
if [ -z $BUILD_LOCATION ]; then
    BUILD_LOCATION="/var/cache/mythbuntu_build"
fi

###############################################################################################
#  The following does *not* need to be changed.  It is fully controlled via the environment   #
#  variables declared above.                                                                  #
###############################################################################################
#Populated variables used in build process
export DEBEMAIL="packages@mythbuntu.org"
export DEBFULLNAME="Mythbuntu Automated Package Builder"
if [ ! -z "$SVN_MINOR_RELEASE" ]; then    
    SVN_RELEASE="0.$SVN_MAJOR_RELEASE.$SVN_MINOR_RELEASE"
else
    SVN_RELEASE="0.$SVN_MAJOR_RELEASE"
fi
if [ "$SVN_TYPE" = "fixes" ]; then
    MYTHTV_SVN_BRANCH="http://svn.mythtv.org/svn/branches/release-0-$SVN_MAJOR_RELEASE-fixes/mythtv"
    MYTHPLUGINS_SVN_BRANCH="http://svn.mythtv.org/svn/branches/release-0-$SVN_MAJOR_RELEASE-fixes/mythplugins"
elif [ "$SVN_TYPE" = "trunk" ]; then
    MYTHTV_SVN_BRANCH="http://svn.mythtv.org/svn/branches/trunk/mythtv"
    MYTHPLUGINS_SVN_BRANCH="http://svn.mythtv.org/svn/branches/trunk/mythplugins"
else
    echo "I don't understand how to build $SVN_TYPE"
    exit 55
fi
SVN_REVISION=`svn info $MYTHTV_SVN_BRANCH | grep Revision | cut -b 11-`

#Make sure our target directory structure is sane for falcon
#also automatically add a new target if we are doing a new
#ubuntu release
cd $BUILD_LOCATION
mkdir -p builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE
if [ ! -e builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE/desc ]
then
    cat <<EOCHROOT > builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE/desc
MythTV $SVN_RELEASE $SVN_TYPE Packages automatically built weekly for $UBUNTU_RELEASE
EOCHROOT
fi
if [ ! -e builds/pool/$UBUNTU_RELEASE/desc ]
then
    cat <<EOCHROOT > builds/pool/$UBUNTU_RELEASE/desc
Mythbuntu packages built for $UBUNTU_RELEASE
EOCHROOT
fi
if [ ! -e builds/pool/$UBUNTU_RELEASE/falcon.ini ]
then
        cat <<EOCHROOT > builds/pool/$UBUNTU_RELEASE/falcon.ini
[falcon]
version=$UBUNTU_VERSION
EOCHROOT
fi
if [ ! -d work/debian-mythtv ]
then
    echo "Unable to continue without a work/debian-mythtv directory"
    exit 1
fi
if [ ! -d work/debian-mythplugins ]
then
    echo "Unable to continue without a work/debian-mythplugins directory"
    exit 1
fi
cd work

# Checkout and produce a debian source package for 'mythtv'
# Place this package in ../builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE
if [ -d mythtv ]
then
    cd mythtv
    svn update
    cd ..
    mv mythtv mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
else
    svn co $MYTHTV_SVN_BRANCH mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
fi
tar czf mythtv_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION.orig.tar.gz  mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION --exclude .svn
mv debian-mythtv mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION/debian
cd mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
if [ ! -e debian/changelog ]
then
        cp debian/changelog.in debian/changelog
fi
dch -D $UBUNTU_RELEASE -v $SVN_RELEASE+$SVN_TYPE$SVN_REVISION-0.0ubuntu0mythbuntu1 "Automated Weekly Build, no debian/* changes."
debuild -S -i
mv debian ../debian-mythtv
cd ..
mv mythtv-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION mythtv
mv mythtv_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION.orig.tar.gz $BUILD_LOCATION/builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE
mv mythtv_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION-0.0ubuntu0mythbuntu1* $BUILD_LOCATION/builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE

# Checkout and produce a debian source package for 'mythplugins'
# Place this package in ../builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE
if [ -d mythplugins ]
then
    cd mythplugins
    svn update
    cd ..
    mv mythplugins mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
else
    svn co $MYTHPLUGINS_SVN_BRANCH mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
fi
tar czf mythplugins_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION.orig.tar.gz  mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION --exclude .svn
mv debian-mythplugins mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION/debian
cd mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION
if [ ! -e debian/changelog ]
then
    cp debian/changelog.in debian/changelog
fi
dch -D $UBUNTU_RELEASE -v $SVN_RELEASE+$SVN_TYPE$SVN_REVISION-0.0ubuntu0mythbuntu1 "Automated Weekly Build, no debian/* changes."
debuild -S -i
mv debian ../debian-mythplugins
cd ..
mv mythplugins-$SVN_RELEASE+$SVN_TYPE$SVN_REVISION mythplugins
mv mythplugins_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION.orig.tar.gz $BUILD_LOCATION/builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE
mv mythplugins_$SVN_RELEASE+$SVN_TYPE$SVN_REVISION-0.0ubuntu0mythbuntu1* $BUILD_LOCATION/builds/pool/$UBUNTU_RELEASE/weekly-$SVN_TYPE

# Queue these packages on the buildd's
########
# TODO #
########

# Update falcon to reflect source packages
# Buildd results will be added later
#####
# Note, be sure not to do falcon html here
# We may not have a binary-* directory yet, so it will error out
falcon update
